Struct Config

pub struct Config {
Show 14 fields pub port: u16, pub name: String, pub description: String, pub static_dir: PathBufD, pub media_dir: PathBufD, pub captcha: HCaptchaConfig, pub real_ip_header: Option<String>, pub registration_enabled: bool, pub host: String, pub snowflake_server_id: usize, pub blocked_hosts: Vec<String>, pub tiers: Tiers, pub alert: String, pub templates: TemplatesConfig,
}
Configuration file

Fields

port: u16

The port to serve the server on

name: String

The name of the site

description: String

The description of the site

static_dir: PathBufD

The location of the static directory, should not be supplied manually as it will be overwritten with ./.config/static

media_dir: PathBufD

The location of media uploads on the file system

captcha: HCaptchaConfig

HCaptcha configuration

real_ip_header: Option<String>

The name of the header used for reading user IP address

registration_enabled: bool

If new profile registration is enabled

host: String

The origin of the public server (ex: “https://rainbeam.net”)

Used in embeds and links.

snowflake_server_id: usize

The server ID for ID generation

blocked_hosts: Vec<String>

A list of image hosts that are blocked

tiers: Tiers

Tiered benefits

alert: String

A global site announcement shown at the top of the page

templates: TemplatesConfig

Template configuration.

Implementations

Source

impl Config

pub fn read(contents: String) -> Self

Read configuration file into Config

pub fn get_config() -> Self

Pull configuration file

pub fn update_config(contents: Self) -> Result<()>

Update configuration file