rainbeam_shared

Module fs

Fs access utilities

This is essentially a wrapper around standard fs, so it’s just to keep things similar.

Structs

  • Metadata information about a file.

Functions

  • Append to a file given its path and data
  • Returns the canonical, absolute form of a path with all intermediate components normalized and symbolic links resolved.
  • Creates a new, empty directory at the provided path
  • Get a path’s metadata
  • Given a path, queries the file system to get information about a file, directory, etc.
  • Create a directory if it does not already exist
  • cat
  • Returns an iterator over the entries within a directory.
  • Reads the entire contents of a file into a string.
  • Removes a directory at this path, after removing all its contents. Use carefully!
  • Removes a file from the filesystem.
  • rm for only files
  • rm -r for only directories
  • Reads the entire contents of a file into a bytes vector.
  • Writes a slice as the entire contents of a file.
  • touch
  • Write to a file given its path and data

Type Aliases